@@ -11,7 +11,7 @@ import os
 import sys
 from io import StringIO
 from math import floor
-import alac
+from alacorder import alac
 import re
 import warnings
 
@@ -26,7 +26,7 @@ print('''
      / ___ |/ / /_/ / /__/ /_/ / /  / /_/ /  __/ /    
     /_/  |_/_/\\__,_/\\___/\\____/_/   \\__,_/\\___/_/     
                                                                                                                                                                                         
-        ALACORDER beta 7.4.9.9.7
+        ALACORDER beta 7.4.9.9.9
         by Sam Robson   
 
     Alacorder processes case detail PDFs into data tables
@@ -172,6 +172,9 @@ Enter path or skip:
 ''')
     try:
         info = "".join(input()).strip()
+        if len(info) < 2:
+            a = alac.config(in_dir, xpath)
+            alac.writeArchive(a)
     except EOFError:
         a = alac.config(in_dir, xpath)
         alac.writeArchive(a)
