@@ -6,7 +6,7 @@
 #     /_/  |_/_/\__,_/\___/\____/_/   \__,_/\___/_/     
 #
 #
-#       ALACORDER beta 7.4.9.9.7
+#       ALACORDER beta 7.4.9.9.9
 #       by Sam Robson
 #
 
@@ -130,8 +130,8 @@ def config(in_path, out_path="", flags="", print_log=True, warn=False, save_arch
 
 	if input_cap == True:
 		contents = contents[0:max_cases]
-
-	case_max = len(contents)
+	if len(contents) != len(paths) and len(contents) + len(paths) > 0:
+		case_max = len(contents) + len(paths)
 
 	if pd.Series(contents).shape == 0:
 		raise Exception("No cases found in input path! (" + in_path + ")")
@@ -141,17 +141,26 @@ def config(in_path, out_path="", flags="", print_log=True, warn=False, save_arch
 	if origin == "directory" and set_batch == 0:
 		batchsize = 500
 	if set_batch > 0:
-		batchsize = set_batch
+		batchsize = case_max
 
 	tot_batches = math.ceil(case_max / batchsize)
-	batches = np.array_split(contents, tot_batches)
-	batchsize = len(batches[0])
+	try:
+		batches = np.array_split(contents, tot_batches)
+	except ValueError:
+		batches = contents + paths
+	batchsize = case_max
 	
 	write = True if out_ext != "no_export" else False
 
 	if print_log == True:
 		print(f"\nInitial configuration succeeded!\n\nIn:   {in_path} \nOut:    {out_path}\n\n{case_max} cases...\n")
 
+	if len(contents) < 2:
+		contents = paths
+	if len(paths) < 2:
+		paths = contents
+
+
 	conf = pd.Series({
 		'in_path': in_path,
 		'out_path': out_path,
@@ -768,7 +777,7 @@ def getFeeSheet(text: str, cnum: str):
 		try:
 			adminfeerows = pd.Series(actives).str.strip().str.split(" ")[1].str.strip()
 		except (IndexError, AttributeError):
-			adminfeerows = pd.Series()
+			adminfeerows = pd.Series([pd.nan * actives.shape[0]])
 		
 
 		feesheet = pd.DataFrame({
@@ -797,7 +806,7 @@ def getFeeSheet(text: str, cnum: str):
 			'AmtHold': thold
 		}
 
-
+		feesheet = feesheet.dropna()
 		feesheet = feesheet.append(totalrdf, ignore_index=True)
 		feesheet['Code'] = feesheet['Code'].astype("category")
 		feesheet['Payor'] = feesheet['Payor'].astype("category")
@@ -977,7 +986,7 @@ def log_complete(conf, start_time):
 	completion_time = time.time()
 	elapsed = completion_time - start_time
 	cases_per_sec = case_max/elapsed
-	print(f'''
+	print(f'''\n\n
 		  ___    __                          __         
 		 /   |  / /___  _________  _________/ /__  _____
 		/ /| | / / __ `/ ___/ __ \\/ ___/ __  / _ \\/ ___/
@@ -986,7 +995,7 @@ def log_complete(conf, start_time):
 
 
 
-	ALACORDER beta 7.4.9.9.7
+	ALACORDER beta 7.4.9.9.9
 	by Sam Robson   
 
 	Searched {path_in} 
